@@ -538,6 +538,91 @@ class File:
         )
 
 
+class SourceSegyFile:
+    """Represents a raw SEGY file as used in the seismicstore-aware API, particularly for ingestion.
+
+    Attributes:
+        uuid (str): The unique string-based uuid of a source segy file.
+        id (int): A 64-bit integer that represents the source file internally within the seismic service.
+        external_id (str): A string-based user id that uniquely identifies the file.
+        name (str): Non-unique string that describes the file.
+        metadata (Mapping[str, str]): User-provided metadata in the form of a string to string mapping
+        segy_overrides (SegyOverrides): 
+
+    """
+
+    uuid: str
+    id: int
+    external_id: str
+    name: str
+    metadata: Mapping[str, str]
+    segy_overrides: "SegyOverrides"
+
+    def __init__(self, *, uuid, id, external_id, name, metadata, segy_overrides):
+        self.uuid = uuid
+        self.id = id
+        self.external_id = external_id
+        self.name = name
+        self.metadata = metadata
+        self.segy_overrides = segy_overrides
+
+    @staticmethod
+    def from_proto(proto) -> "SourceSegyFile":
+        uuid = proto.uuid
+        id = proto.id
+        external_id = proto.external_id.external_id
+        name = proto.name
+        metadata = proto.metadata
+        segy_overrides = SegyOverrides.from_proto(proto.segy_overrides)
+
+        return SourceSegyFile(
+            uuid=uuid, id=id, external_id=external_id, name=name, metadata=metadata, segy_overrides=segy_overrides
+        )
+
+
+class SegyOverrides:
+    """A set of SegY header overrides for a given ingested file.
+    
+    Attributes:
+        inline_offset (Optional[int])
+        crossline_offset (Optional[int])
+        cdp_x_offset (Optional[int])
+        cdp_y_offset (Optional[int])
+        source_group_scalar_override (Optional[float])
+    """
+
+    inline_offset: Optional[int]
+    crossline_offset: Optional[int]
+    cdp_x_offset: Optional[int]
+    cdp_y_offset: Optional[int]
+    source_group_scalar_override: (Optional[float])
+
+    def __init__(self, *, inline_offset, crossline_offset, cdp_x_offset, cdp_y_offset, source_group_scalar_override):
+        self.inline_offset = inline_offset
+        self.crossline_offset = crossline_offset
+        self.cdp_x_offset = cdp_x_offset
+        self.cdp_y_offset = cdp_y_offset
+        self.source_group_scalar_override = source_group_scalar_override
+
+    @staticmethod
+    def from_proto(proto) -> "SegyOverrides":
+        """Convert a SegyOverrides proto into a python object"""
+        inline_offset = proto.inline_offset.value if proto.HasField("inline_offset") else None
+        crossline_offset = proto.crossline_offset.value if proto.HasField("crossline_offset") else None
+        cdp_x_offset = proto.cdp_x_offset.value if proto.HasField("cdp_x_offset") else None
+        cdp_y_offset = proto.cdp_y_offset.value if proto.HasField("cdp_y_offset") else None
+        source_group_scalar_override = (
+            proto.source_group_scalar_override.value if proto.HasField("source_group_scalar_override") else None
+        )
+        return SegyOverrides(
+            inline_offset=inline_offset,
+            crossline_offset=crossline_offset,
+            cdp_x_offset=cdp_x_offset,
+            cdp_y_offset=cdp_y_offset,
+            source_group_scalar_override=source_group_scalar_override,
+        )
+
+
 class Geometry:
     """Represents a CRS + shape, in either a WKT format or a GeoJSON.
 
